<?php
/*
Plugin Name: WP Auto Linker
Plugin URI: https://ebot.my.id
Description: Plugin untuk menambahkan link internal otomatis berdasarkan judul postingan.
Version: 1.0
Author: Rifan Muazin
Author URI: https://ebot.my.id
*/

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

// Fungsi untuk menghapus kata umum
function wp_auto_linker_remove_common_words($title) {
    $common_words = array(
        'dan', 'di', 'and', 'of', 'the', 'a', 'an', 'in', 'on', 'at', 'to', 'for', 'with', 'about', 'as', 'by', 
        'is', 'it', 'this', 'that', 'these', 'those', 'are', 'was', 'were', 'be', 'been', 'am', 'do', 'does', 'did', 
        'but', 'or', 'nor', 'so', 'yet', 'if', 'than', 'then', 'when', 'while', 'where', 'which', 'who', 'whom', 'whose',
        'all', 'any', 'both', 'each', 'few', 'many', 'most', 'some', 'such', 'no', 'not', 'only', 'own', 'same', 'so', 
        'than', 'too', 'very', 'can', 'will', 'just', 'should', 'could', 'would', 'here', 'there', 'how', 'i', 'you', 
        'he', 'she', 'we', 'they', 'me', 'him', 'her', 'us', 'them', 'my', 'your', 'his', 'its', 'our', 'their', 'mine', 
        'yours', 'hers', 'ours', 'theirs', 'apa', 'siapa', 'kenapa', 'mengapa', 'bagaimana', 'seperti', 'mereka', 'kami', 
        'kita', 'dia', 'itu', 'ini', 'ke', 'dari', 'pada', 'untuk', 'sebagai', 'dengan', 'tanpa', 'hingga', 'sampai', 
        'karena', 'supaya', 'sebab', 'dan', 'atau', 'tetapi', 'namun', 'bahkan', 'lagipula', 'malahan', 'melainkan', 
        'padahal', 'sedangkan', 'sejak', 'selama', 'seraya', 'setelah', 'sehingga', 'meskipun', 'walaupun'
    );

    $title_words = explode(' ', $title);
    $filtered_words = array_filter($title_words, function($word) use ($common_words) {
        return !in_array(strtolower($word), $common_words);
    });

    return implode(' ', $filtered_words);
}

// Fungsi untuk menambahkan link internal ke kata-kata di judul
function wp_auto_linker_add_internal_links($content) {
    global $post;

    if (get_post_meta($post->ID, '_wp_auto_linker_done', true)) {
        return $content; // Jika sudah diproses, return content as is
    }

    $title = $post->post_title;
    $filtered_title = wp_auto_linker_remove_common_words($title);

    $title_words = explode(' ', $filtered_title);
    foreach ($title_words as $word) {
        $pattern = '/\b' . preg_quote($word, '/') . '\b/i';
        $replacement = '<a href="' . get_permalink($post->ID) . '">' . $word . '</a>';
        $content = preg_replace($pattern, $replacement, $content, 1); // Replace only the first occurrence
    }

    // Tandai bahwa postingan sudah diproses
    update_post_meta($post->ID, '_wp_auto_linker_done', 1);

    return $content;
}

add_filter('the_content', 'wp_auto_linker_add_internal_links');

// Fungsi untuk menghapus metadata saat postingan diupdate
function wp_auto_linker_reset_meta($post_id) {
    if (get_post_type($post_id) === 'post') {
        delete_post_meta($post_id, '_wp_auto_linker_done');
    }
}

add_action('save_post', 'wp_auto_linker_reset_meta');
?>
